shithub: jbig2

Download patch

ref: 8f1012147073d64f79de947930f1ac6b4fca959a
parent: 30beab7a07268fe5ccd204fdc621a7fee3489e8f
author: giles <giles@ded80894-8fb9-0310-811b-c03f3676ab4d>
date: Fri Jun 21 19:11:29 EDT 2002

restore original behavior for -DOUTPUT_PBM


git-svn-id: http://svn.ghostscript.com/jbig2dec/trunk@80 ded80894-8fb9-0310-811b-c03f3676ab4d

--- a/jbig2_symbol_dict.c
+++ b/jbig2_symbol_dict.c
@@ -8,7 +8,7 @@
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    $Id: jbig2_symbol_dict.c,v 1.7 2002/06/21 22:56:54 giles Exp $
+    $Id: jbig2_symbol_dict.c,v 1.8 2002/06/21 23:11:29 giles Exp $
 */
 
 #include <stddef.h>
@@ -21,7 +21,12 @@
 #include "jbig2_generic.h"
 #include "jbig2_symbol_dict.h"
 
+#ifdef OUTPUT_PBM
+#include <stdio.h>
+#include "jbig2_image.h"
+#endif
 
+
 /* Table 13 */
 typedef struct {
   bool SDHUFF;
@@ -145,8 +150,10 @@
 						     as,
 						     image, GB_stats);
 		  /* todo: handle errors */
-		  /* todo: stash gbreg in SDNEWSYMS */
-						     
+		  /* todo: stash image in SDNEWSYMS */
+#ifdef OUTPUT_PBM
+                  jbig2_image_write_pbm(image, stdout);
+#endif
 		}
 	    }